==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/storagesync/kotlin/inputs/GetSyncGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagesync.kotlin.inputs

import com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property storageSyncServiceName Name of Storage Sync Service resource.
 * @property syncGroupName Name of Sync Group resource.
 */
public data class GetSyncGroupPlainArgs(
    public val resourceGroupName: String,
    public val storageSyncServiceName: String,
    public val syncGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs =
        com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .storageSyncServiceName(storageSyncServiceName.let({ args0 -> args0 }))
            .syncGroupName(syncGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSyncGroupPlainArgs].
 */
@PulumiTagMarker
public class GetSyncGroupPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var storageSyncServiceName: String? = null

    private var syncGroupName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("fhwrumcthpbwqycd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of Storage Sync Service resource.
     */
    @JvmName("bohoswpuabhbgvgh")
    public suspend fun storageSyncServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.storageSyncServiceName = mapped
    }

    /**
     * @param value Name of Sync Group resource.
     */
    @JvmName("lnkrmtqrqmcsaqaq")
    public suspend fun syncGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.syncGroupName = mapped
    }

    internal fun build(): GetSyncGroupPlainArgs = GetSyncGroupPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        storageSyncServiceName = storageSyncServiceName ?: throw
            PulumiNullFieldException("storageSyncServiceName"),
        syncGroupName = syncGroupName ?: throw PulumiNullFieldException("syncGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/storagesync/kotlin/inputs/GetSyncGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagesync.kotlin.inputs

import com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property storageSyncServiceName Name of Storage Sync Service resource.
 * @property syncGroupName Name of Sync Group resource.
 */
public data class GetSyncGroupPlainArgs(
    public val resourceGroupName: String,
    public val storageSyncServiceName: String,
    public val syncGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs =
        com.pulumi.azurenative.storagesync.inputs.GetSyncGroupPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .storageSyncServiceName(storageSyncServiceName.let({ args0 -> args0 }))
            .syncGroupName(syncGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSyncGroupPlainArgs].
 */
@PulumiTagMarker
public class GetSyncGroupPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var storageSyncServiceName: String? = null

    private var syncGroupName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("cjiqdcwwwxygagxy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of Storage Sync Service resource.
     */
    @JvmName("kjyqsxajoplxccts")
    public suspend fun storageSyncServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.storageSyncServiceName = mapped
    }

    /**
     * @param value Name of Sync Group resource.
     */
    @JvmName("nxyypjontnbktjyk")
    public suspend fun syncGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.syncGroupName = mapped
    }

    internal fun build(): GetSyncGroupPlainArgs = GetSyncGroupPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        storageSyncServiceName = storageSyncServiceName ?: throw
            PulumiNullFieldException("storageSyncServiceName"),
        syncGroupName = syncGroupName ?: throw PulumiNullFieldException("syncGroupName"),
    )
}
